pub struct SimpleVerifier;Available on crate features
ed25519 or secp256k1 or secp256r1 or zklogin only.Trait Implementations
Sourceimpl Verifier<SimpleSignature> for SimpleVerifier
impl Verifier<SimpleSignature> for SimpleVerifier
Sourcefn verify(
&self,
message: &[u8],
signature: &SimpleSignature,
) -> Result<(), SignatureError>
fn verify( &self, message: &[u8], signature: &SimpleSignature, ) -> Result<(), SignatureError>
Use
Self to verify that the provided signature for a given message
bytestring is authentic. Read moreSourceimpl Verifier<UserSignature> for SimpleVerifier
impl Verifier<UserSignature> for SimpleVerifier
Sourcefn verify(
&self,
message: &[u8],
signature: &UserSignature,
) -> Result<(), SignatureError>
fn verify( &self, message: &[u8], signature: &UserSignature, ) -> Result<(), SignatureError>
Use
Self to verify that the provided signature for a given message
bytestring is authentic. Read moreAuto Trait Implementations
impl Freeze for SimpleVerifier
impl RefUnwindSafe for SimpleVerifier
impl Send for SimpleVerifier
impl Sync for SimpleVerifier
impl Unpin for SimpleVerifier
impl UnsafeUnpin for SimpleVerifier
impl UnwindSafe for SimpleVerifier